/*******************************************************************************
*   Author       -  Kiraly Tibor
*                   http://www.tkiraaly.hu
*   Date         -  2013.07.19.
*   Chip         -  Atmel ATmega8
*   Compiler     -  avr-gcc (WinAVR)
*
*   KT IRR - Infra Reed Recorder
*   
********************************************************************************
*
*   AVR  4 - PD2 (INT0) - TSOP 2236 2
*   AVR  1 - NRES       - switch 4k7-tel felhuzva
*   AVR 15 - PB1        - LED 470R-el felhuzva
*
*******************************************************************************/

#define F_CPU                4000000             // orajel 4MHz
#define MINTA                51




#include "tkiraaly_atmega8.h"
#include <util/delay.h>




#define OPTO_0               BTC( PIND, 2)
#define OPTO_1               BTS( PIND, 2)




void usart_putc( U8);                  // USART egy karakter kuldese
void usart_puthexc( U8);               // 1 hexadecimalis szamjegy kiirasa
void usart_puthex( U8);                // 1 byte kiirasa hexadecimalisan




int main( void)
{
   U8 d[ MINTA+ 1];                    // mert idok
   U8 c;                               // szamlalo
   U8 i;                               // index d[]-hez
   USART_SET_9600_8N1;
   PIN_B1_OUT;                         // LED

   usart_putc('K');
   usart_putc('T');
   usart_putc('-');
   usart_putc('I');
   usart_putc('R');
   usart_putc('R');
   usart_putc( 13);

   while( OPTO_1);                     // varakozas, amig nincs jel
   c= 0;
   while( OPTO_0)                      // bevezeto szakasz merese msec
   {
      _delay_us(100);
      c++;
   }
   d[ 0]= c;
   i= 1;
   while( i < MINTA)
   {
      c= 0;
      while( OPTO_1)                   // szunet
      {
         _delay_us(14);                // 1/(36kHz*2)
         if( c < 255) c++;             // ne forduljon at
      }
      d[ i]= c;
      i++;
      c= 0;
      while( OPTO_0)                   // jel
      {
         _delay_us(14);
         if( c < 255) c++;
      }
      d[ i]= c;
      i++;
   }
   i= 0;                               // kiiras
   usart_puthex( d[ i++]);
   usart_putc( '-');
   while( i < MINTA)
   {
       usart_putc( '/');
       usart_puthex( d[ i++]);
       usart_putc( '\\');
       usart_puthex( d[ i++]);
   }
   usart_putc( 13);
   for(;;);
   return 0;
}



        
void usart_putc( U8 c)                 // USART egy karakter kuldese
{
    while( BTC( UCSRA, UDRE));         // 1, ha kesz az adat fogadasara
    UDR= c;
}



 
void usart_puthexc( U8 c)              // 1 hexadecimalis szamjegy kiirasa
{
   c&= 0x0F;
   if( c < 10) c+= '0';
   else        c+= 'A'- 10;
   usart_putc( c);
}



 
void usart_puthex( U8 c)               // 1 byte kiirasa hexadecimalisan
{
   usart_puthexc( c >> 4);
   usart_puthexc( c);
}
